paidiverpy.utils.base_model
===========================

.. py:module:: paidiverpy.utils.base_model

.. autoapi-nested-parse::

   Dynamic classes for configuration.

   ..
       !! processed by numpydoc !!


Classes
-------

.. autoapisummary::

   paidiverpy.utils.base_model.BaseModel


Module Contents
---------------

.. py:class:: BaseModel(/, **data: Any)

   Bases: :py:obj:`pydantic.BaseModel`


   
   Base model for dynamic configurations.
















   ..
       !! processed by numpydoc !!

   .. py:method:: to_dict(convert_path: bool = True) -> dict[str, Any]

      
      Convert model to dictionary, excluding None and empty values.
















      ..
          !! processed by numpydoc !!


